ReferenceExpression

Enum ReferenceExpression 

pub enum ReferenceExpression<T: Clone> {
    Constant(T),
    Variable(usize),
    Table(TableExpression<T>),
}
Expression referring to a constant or a variable.

Variants



Constant(T)

Constant.



Variable(usize)

Variable index.



Table(TableExpression<T>)

Constant in a table.

Implementations

Source

impl<T: Clone> ReferenceExpression<T>

pub fn simplify( &self, registry: &TableRegistry, tables: &TableData<T>, ) -> ReferenceExpression<T>

Returns a simplified version by precomputation.

Panics

Panics if a min/max reduce operation is performed on an empty set or vector.

Source

impl ReferenceExpression<Set>

pub fn eval<'a, S: StateInterface>( &'a self, state: &'a S, function_cache: &mut StateFunctionCache, state_functions: &StateFunctions, registry: &'a TableRegistry, ) -> &'a Set

Returns the evaluation result.

Panics

Panics if the cost of the transition state is used or a min/max reduce operation is performed on an empty set or vector.

Source

impl ReferenceExpression<Vector>

pub fn eval<'a, U: StateInterface>( &'a self, state: &'a U, function_cache: &mut StateFunctionCache, state_functions: &StateFunctions, registry: &'a TableRegistry, ) -> &'a Vector

Returns the evaluation result.

Panics

Panics if the cost of the transition state is used or a min/max reduce operation is performed on an empty set or vector.