pub enum BinaryOperator {
Add,
Sub,
Mul,
Div,
Rem,
Max,
Min,
}Expand description
Binary arithmetic operator.
Variants
Implementations
Sourceimpl BinaryOperator
impl BinaryOperator
Sourcepub fn eval<T: Num + PartialOrd>(&self, a: T, b: T) -> T
pub fn eval<T: Num + PartialOrd>(&self, a: T, b: T) -> T
Returns the result of the evaluation.
Sourcepub fn eval_operation_x<T: Num + PartialOrd + Copy>(
&self,
x: T,
y: Vec<T>,
) -> Vec<T>
pub fn eval_operation_x<T: Num + PartialOrd + Copy>( &self, x: T, y: Vec<T>, ) -> Vec<T>
Returns the result of the evaluation with x and each element in y.
Sourcepub fn eval_operation_y<T: Num + PartialOrd + Copy>(
&self,
x: Vec<T>,
y: T,
) -> Vec<T>
pub fn eval_operation_y<T: Num + PartialOrd + Copy>( &self, x: Vec<T>, y: T, ) -> Vec<T>
Returns the result of the evaluation with each element in x and y.
Sourcepub fn eval_vector_operation_in_x<T: Num + PartialOrd + Copy>(
&self,
x: Vec<T>,
y: &[T],
) -> Vec<T>
pub fn eval_vector_operation_in_x<T: Num + PartialOrd + Copy>( &self, x: Vec<T>, y: &[T], ) -> Vec<T>
Returns the result of the evaluation with each element in x and each element in y.
If y is longer than x, the result is truncated to the length of x.
Sourcepub fn eval_vector_operation_in_y<T: Num + PartialOrd + Copy>(
&self,
x: &[T],
y: Vec<T>,
) -> Vec<T>
pub fn eval_vector_operation_in_y<T: Num + PartialOrd + Copy>( &self, x: &[T], y: Vec<T>, ) -> Vec<T>
Returns the result of the evaluation with each element in x and each element in y.
If x is longer than y, the result is truncated to the length of y.