pub enum VectorExpression {
Reference(ReferenceExpression<Vector>),
Indices(Box<VectorExpression>),
Reverse(Box<VectorExpression>),
Set(ElementExpression, Box<VectorExpression>, ElementExpression),
Push(ElementExpression, Box<VectorExpression>),
Pop(Box<VectorExpression>),
FromSet(Box<SetExpression>),
If(Box<Condition>, Box<VectorExpression>, Box<VectorExpression>),
}Expand description
Vector expression.
Variants
Reference(ReferenceExpression<Vector>)
Reference to a constant or a variable.
Indices(Box<VectorExpression>)
Indices of a vector.
Reverse(Box<VectorExpression>)
Reverse a vector.
Set(ElementExpression, Box<VectorExpression>, ElementExpression)
Set an element in a vector.
Push(ElementExpression, Box<VectorExpression>)
Push an element to a vector.
Pop(Box<VectorExpression>)
Pop an element from a vector.
FromSet(Box<SetExpression>)
Conversion from a set.
If(Box<Condition>, Box<VectorExpression>, Box<VectorExpression>)
If-then-else expression, which returns the first one if the condition holds and the second one otherwise.
Implementations
Sourceimpl VectorExpression
impl VectorExpression
Sourcepub fn eval<T: StateInterface>(
&self,
state: &T,
function_cache: &mut StateFunctionCache,
state_functions: &StateFunctions,
registry: &TableRegistry,
) -> Vector
pub fn eval<T: StateInterface>( &self, state: &T, function_cache: &mut StateFunctionCache, state_functions: &StateFunctions, registry: &TableRegistry, ) -> Vector
Returns the evaluation result.
Panics
Panics if the cost of the transition state is used or a min/max reduce operation is performed on an empty set or vector.
Sourcepub fn simplify(&self, registry: &TableRegistry) -> VectorExpression
pub fn simplify(&self, registry: &TableRegistry) -> VectorExpression
Returns a simplified version by precomputation.
Panics
Panics if the cost of the transition state is used or a min/max reduce operation is performed on an empty set or vector.